<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 10.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop;

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

$classes = 'woocommerce-post';

// get theme customizer data
$sProduct_media 	= royal_get_option( 'royal_sProduct_media' );
$sProduct_title 	= royal_get_option( 'royal_sProduct_title' );
$sProduct_cats		= royal_get_option( 'royal_sProduct_cats' );
$sProduct_rating 	= royal_get_option( 'royal_sProduct_rating' );
$sProduct_price 	= royal_get_option( 'royal_sProduct_price' );
$sProduct_addcart 	= royal_get_option( 'royal_sProduct_addcart' );
$sProduct_effects	= royal_get_option( 'royal_sProduct_effects' );


?>
<li <?php post_class( $classes ); ?>>

	<div class="woocommerce-post-inner">

	<!-- Post Text -->
	<div class="woopost-text-wrap">

		<?php if ( $sProduct_title['position'] === 'above' ) : ?>
			<div class="woopost-title-wrap">
				<h3 class="woopost-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
				<?php if ( $sProduct_price['position'] === 'title' ) : ?>
					<?php woocommerce_template_loop_price(); ?>
					<div class="clear"></div>
				<?php endif; ?>
			</div>
		<?php endif; ?>
			
		<?php if ( $sProduct_cats['position'] === 'above' ) : ?>
			<div class="woopost-categories">
				<span class="woopost-cats-in"><?php echo wc_get_product_category_list( $post->ID ); ?></span>
			</div>
		<?php endif; ?>

		<?php if ( $sProduct_rating['position'] === 'above' ) : ?>
			<div class="woopost-rating">
				<div class="woopost-rating-in">
				<?php
					for ( $i = 1; $i < 6; $i++ ) {
						$star = ( $i <= $product->get_average_rating() ) ? '&starf;' : '&star;';
						$class = ( $i <= $product->get_average_rating() ) ? ' class="woopost-rated"' : ' class="woopost-unrated"';
						echo '<span'. $class .'>'. $star .'</span>';
					}
				?>
				</div>
			</div>
		<?php endif; ?>

		<?php if ( $sProduct_price['position'] === 'above' ) : ?>
			<?php woocommerce_template_loop_price(); ?>
		<?php endif; ?>

		<?php if ( $sProduct_addcart['position'] === 'above' ) : ?>
			<?php woocommerce_template_loop_add_to_cart(); ?>
			<?php if ( $sProduct_price['position'] === 'addcart' ) : ?>
				<?php woocommerce_template_loop_price(); ?>
				<div class="clear"></div>
			<?php endif; ?>
		<?php endif; ?>

	</div>

	<!-- Post Media -->
	<div class="woopost-media-wrap">

		<div class="woopost-media-in-wrap">

			<!-- Post Thumbnail -->
			<div class="woopost-media" data-grayscale="<?php echo ''. $sProduct_effects['grayscale_label']; ?>" data-grayscale-trans="<?php echo ''. $sProduct_effects['grayscale_trans']; ?>">

				<!-- Decorational Triangle -->
				<div class="wootriangle-wrap"></div>

				<?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
				
			</div>

			<?php

				// get portfolio item info hovers
				if ( $sProduct_media['info_hovers_select'] === 'fade' ) {
					$info_hover = $sProduct_media['hover_fade'];
				} elseif ( $sProduct_media['info_hovers_select'] === 'grow' ) {
					$info_hover = $sProduct_media['hover_grow'];
				} elseif ( $sProduct_media['info_hovers_select'] === 'slide' ) {
					$info_hover = $sProduct_media['hover_slide'];
				} elseif ( $sProduct_media['info_hovers_select'] === 'skew' ) {
					$info_hover = $sProduct_media['hover_skew'];
				} elseif ( $sProduct_media['info_hovers_select'] === 'sk-full' ) {
					$info_hover = $sProduct_media['hover_skew_full'];
				} elseif ( $sProduct_media['info_hovers_select'] === 'skfull-fd' ) {
					$info_hover = $sProduct_media['hover_skew_full_fade'];
				}

			?>

			<!-- Post Hovers -->
			<div class="woomedia-hovers-overflow">
			<div class="woomedia-hovers woomedia-hover-<?php echo esc_attr($info_hover); ?>">
				<div class="woomedia-hovers-outer">
					<div class="woomedia-hovers-inner">

						<?php if ( $sProduct_title['position'] === 'hover' ) : ?>
							<div class="woopost-title-wrap">
								<h3 class="woopost-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
								<?php if ( $sProduct_price['position'] === 'title' ) : ?>
									<?php woocommerce_template_loop_price(); ?>
									<div class="clear"></div>
								<?php endif; ?>
							</div>
						<?php endif; ?>

						<?php if ( $sProduct_cats['position'] === 'hover' ) : ?>
							<div class="woopost-categories">
								<span class="woopost-cats-in"><?php echo wc_get_product_category_list( $post->ID ); ?></span>
							</div>
						<?php endif; ?>

						<?php if ( $sProduct_rating['position'] === 'hover' ) : ?>
							<div class="woopost-rating">
								<div class="woopost-rating-in">
								<?php
									for ( $i = 1; $i < 6; $i++ ) {
										$star = ( $i <= $product->get_average_rating() ) ? '&starf;' : '&star;';
										$class = ( $i <= $product->get_average_rating() ) ? ' class="woopost-rated"' : ' class="woopost-unrated"';
										echo '<span'. $class .'>'. $star .'</span>';
									}
								?>
								</div>
							</div>
						<?php endif; ?>

						<?php if ( $sProduct_price['position'] === 'hover' ) : ?>
							<?php woocommerce_template_loop_price(); ?>
						<?php endif; ?>

						<?php if ( $sProduct_addcart['position'] === 'hover' ) : ?>
							<?php woocommerce_template_loop_add_to_cart(); ?>
							<?php if ( $sProduct_price['position'] === 'addcart' ) : ?>
								<?php woocommerce_template_loop_price(); ?>
								<div class="clear"></div>
							<?php endif; ?>
						<?php endif; ?>

						<?php if ( $sProduct_media['link_single'] === true ) : ?>
							<a href="<?php esc_url(the_permalink()); ?>" class="woomedia-hover-link"></a>
						<?php endif; ?>

					</div>
				</div>
			</div>
			</div>

		</div>

	</div>

	<!-- Post Text -->
	<div class="woopost-text-wrap">

		<?php if ( $sProduct_title['position'] === 'below' ) : ?>
			<div class="woopost-title-wrap">
				<h3 class="woopost-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
				<?php if ( $sProduct_price['position'] === 'title' ) : ?>
					<?php woocommerce_template_loop_price(); ?>
					<div class="clear"></div>
				<?php endif; ?>
			</div>
		<?php endif; ?>

		<?php if ( $sProduct_cats['position'] === 'below' ) : ?>
			<div class="woopost-categories">
				<span class="woopost-cats-in"><?php echo wc_get_product_category_list( $post->ID ); ?></span>
			</div>
		<?php endif; ?>

		<?php if ( $sProduct_rating['position'] === 'below' ) : ?>
			<div class="woopost-rating">
				<div class="woopost-rating-in">
				<?php
					for ( $i = 1; $i < 6; $i++ ) {
						$star = ( $i <= $product->get_average_rating() ) ? '&starf;' : '&star;';
						$class = ( $i <= $product->get_average_rating() ) ? ' class="woopost-rated"' : ' class="woopost-unrated"';
						echo '<span'. $class .'>'. $star .'</span>';
					}
				?>
				</div>
			</div>
		<?php endif; ?>

		<?php if ( $sProduct_price['position'] === 'below' ) : ?>
			<?php woocommerce_template_loop_price(); ?>
		<?php endif; ?>

		<?php if ( $sProduct_addcart['position'] === 'below' ) : ?>
			<?php woocommerce_template_loop_add_to_cart(); ?>
			<?php if ( $sProduct_price['position'] === 'addcart' ) : ?>
				<?php woocommerce_template_loop_price(); ?>
				<div class="clear"></div>
			<?php endif; ?>
		<?php endif; ?>

	</div>

	</div>

</li>
