<?php
/**
 * The template for displaying product widget entries.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-widget-reviews.php
 * 
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 10.0
 */
global $product;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews">
	<div id="comments">
		<h4><?php
			if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' && ( $count = $product->get_review_count() ) )
				printf( _n( '%s review for %s', '%s reviews for %s', $count, 'hyperx' ), $count, get_the_title() );
			else
				_e( 'Reviews', 'hyperx' );
		?></h4>

		<?php if ( have_comments() ) : ?>

			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links( apply_filters( 'woocommerce_comment_pagination_args', array(
					'prev_text' => '&larr;',
					'next_text' => '&rarr;',
					'type'      => 'list',
				) ) );
				echo '</nav>';
			endif; ?>

		<?php else : ?>

			<p class="woocommerce-noreviews"><?php _e( 'There are no reviews yet.', 'hyperx' ); ?></p>

		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div id="review_form_wrapper">
			<div id="review_form">
				<?php
					$commenter = wp_get_current_commenter();

					$comment_form = array(
						'title_reply'          => have_comments() ? __( 'Add a review', 'hyperx' ) : __( 'Be the first to review', 'hyperx' ) . ' &ldquo;' . get_the_title() . '&rdquo;',
						'title_reply_to'       => __( 'Leave a Reply to %s', 'hyperx' ),
						'comment_notes_before' => '',
						'comment_notes_after'  => '',
						'fields'               => array(
							'author' => '<p class="comment-form-author">' .
							            '<input class="rf-input" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" placeholder="'. __( 'Name', 'hyperx' ) .'"/></p>',
							'email'  => '<p class="comment-form-email">' .
							            '<input class="rf-input" id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" aria-required="true"  placeholder="'. __( 'Email', 'hyperx' ) .'"/></p>',
						),
						'label_submit'  => __( 'Submit', 'hyperx' ),
						'logged_in_as'  => '',
						'comment_field' => ''
					);

					if ( $account_page_url = wc_get_page_permalink( 'myaccount' ) ) {
						$comment_form['must_log_in'] = '<p class="must-log-in">' .  sprintf( __( 'You must be <a href="%s">logged in</a> to post a review.', 'hyperx' ), esc_url( $account_page_url ) ) . '</p>';
					}

					if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
						$comment_form['comment_field'] = '<p class="comment-form-rating"><label for="rating">' . __( 'Your Rating', 'hyperx' ) .'</label>
						<div class="woopost-rating">
							<div class="woopost-rating-in">
								<span class="woopost-unrated" data-index="1">&star;</span>
								<span class="woopost-unrated" data-index="2">&star;</span>
								<span class="woopost-unrated" data-index="3">&star;</span>
								<span class="woopost-unrated" data-index="4">&star;</span>
								<span class="woopost-unrated" data-index="5">&star;</span>
							</div>
						</div>
						<select name="rating" id="rating">
							<option value="">' . __( 'Rate&hellip;', 'hyperx' ) . '</option>
							<option value="5">' . __( 'Perfect', 'hyperx' ) . '</option>
							<option value="4">' . __( 'Good', 'hyperx' ) . '</option>
							<option value="3">' . __( 'Average', 'hyperx' ) . '</option>
							<option value="2">' . __( 'Not that bad', 'hyperx' ) . '</option>
							<option value="1">' . __( 'Very Poor', 'hyperx' ) . '</option>
						</select></p>';
					}

					$comment_form['comment_field'] .= '<p class="comment-form-comment"><textarea class="rf-input" id="comment" name="comment" cols="45" rows="8" aria-required="true" placeholder="'. __( 'Your Review', 'hyperx' ) .'"></textarea></p>';

					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php _e( 'Only logged in customers who have purchased this product may leave a review.', 'hyperx' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>
