<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version 10.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $post, $product;

$get_cats = get_the_terms( $post->ID, 'product_cat' );
$get_tags = get_the_terms( $post->ID, 'product_tag' );

?>
<p class="product_meta">

	<?php do_action( 'woocommerce_product_meta_start' ); ?>

	<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

		<span class="sku_wrapper"><?php _e( 'SKU:', 'hyperx' ); ?>
			<span class="sku" itemprop="sku">
				<?php
					if ( $sku = $product->get_sku() ) {
						echo esc_html( $sku );
					} else {
						echo __( 'N/A', 'hyperx' );
					}
				?>
			</span>
		</span>
		<br>

	<?php endif; ?>

	<?php
		if ( $get_cats ) {
			echo wc_get_product_category_list( $post->ID, ', ', '<span class="posted_in">' . _n( 'Category:', 'Categories:', sizeof($get_cats), 'hyperx' ) . ' ', '</span>' );
		}
	?>

	<br>

	<?php 
		if ( $get_tags ) {
			echo wc_get_product_tag_list( $post->ID, ', ', '<span class="tagged_as">' . _n( 'Tag:', 'Tags:', sizeof($get_tags), 'hyperx' ) . ' ', '</span>' );
		}	
	?>

	<?php do_action( 'woocommerce_product_meta_end' ); ?>

</p>
